CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
58 lines
2.0 KiB
C++
58 lines
2.0 KiB
C++
// Copyright © Advanced Micro Devices, Inc., or its affiliates.
|
|
// SPDX-License-Identifier: MIT
|
|
|
|
#include <gtest/gtest.h>
|
|
#include <hip/hip_runtime_api.h>
|
|
|
|
#include <cstdlib>
|
|
#include <string_view>
|
|
|
|
// This test event listener ensures that HIP errors are cleaned up after every test, and will flag
|
|
// tests that don't clean up their own errors
|
|
class HIPErrorHandler : public testing::EmptyTestEventListener
|
|
{
|
|
void OnTestEnd(const testing::TestInfo& test_info) override
|
|
{
|
|
auto hipError = hipGetLastError();
|
|
auto hipExtError = hipExtGetLastError();
|
|
|
|
ASSERT_EQ(hipError, hipSuccess)
|
|
<< " hipGetLastError returned error code " << hipError << " after test "
|
|
<< test_info.test_suite_name() << "." << test_info.name()
|
|
<< ". Error string: " << hipGetErrorString(hipError);
|
|
ASSERT_EQ(hipExtError, hipSuccess)
|
|
<< " hipExtGetLastError returned error code " << hipExtError << " after test "
|
|
<< test_info.test_suite_name() << "." << test_info.name()
|
|
<< ". Error string: " << hipGetErrorString(hipExtError);
|
|
}
|
|
};
|
|
|
|
int main(int argc, char** argv)
|
|
{
|
|
// Child processes spawned by multi-process tests (e.g., perfdb) inherit
|
|
// GTEST_TOTAL_SHARDS/GTEST_SHARD_INDEX from the parent's CI shard.
|
|
// This causes children to run only a subset of their assigned work.
|
|
// Clear sharding env vars so each child runs all filtered tests.
|
|
for(int i = 1; i < argc; ++i)
|
|
{
|
|
if(std::string_view(argv[i]) == "--reset-sharding")
|
|
{
|
|
#ifdef _WIN32
|
|
_putenv_s("GTEST_TOTAL_SHARDS", "");
|
|
_putenv_s("GTEST_SHARD_INDEX", "");
|
|
#else
|
|
unsetenv("GTEST_TOTAL_SHARDS");
|
|
unsetenv("GTEST_SHARD_INDEX");
|
|
#endif
|
|
break;
|
|
}
|
|
}
|
|
|
|
testing::InitGoogleTest(&argc, argv);
|
|
|
|
testing::TestEventListeners& listeners = testing::UnitTest::GetInstance()->listeners();
|
|
listeners.Append(new HIPErrorHandler);
|
|
|
|
return RUN_ALL_TESTS();
|
|
}
|